@@ -513,7 +513,36 @@ analysis_ready_facets = {
         ["/nanostring/normalized_data.csv"],
         "Tabulated data across all samples in a batch",
     ),
-    "RNA": FacetConfig(["/rna/analysis/salmon/quant.sf"]),
+    "RNA": FacetConfig(
+        [
+            "/rna/analysis/star/sorted.bam",
+            "/rna/analysis/star/sorted.bam.bai",
+            "/rna/analysis/star/sorted.bam.stat.txt",
+            "/rna/analysis/star/transcriptome.bam",
+            "/rna/analysis/star/chimeric_out_junction.junction",
+            "/rna/analysis/star/chimeric_out.junction",
+            "/rna/analysis/rseqc/read_distrib.txt",
+            "/rna/analysis/rseqc/tin_score.summary.txt",
+            "/rna/analysis/rseqc/tin_score.txt",
+            "/rna/analysis/salmon/quant.sf",
+            "/rna/analysis/salmon/transcriptome.bam.log",
+            "/rna/analysis/salmon/aux_info_ambig_info.tsv",
+            "/rna/analysis/salmon/aux_info_expected_bias.gz",
+            "/rna/analysis/salmon/aux_info_meta_info.json",
+            "/rna/analysis/salmon/aux_info_fld.gz",
+            "/rna/analysis/salmon/aux_info_observed_bias.gz",
+            "/rna/analysis/salmon/aux_info_observed_bias_3p.gz",
+            "/rna/analysis/salmon/cmd_info.json",
+            "/rna/analysis/salmon/salmon_quant.log",
+            "/rna/analysis/microbiome/addSample_report.txt",
+            "/rna/analysis/microbiome/sample_report.txt",
+            "/rna/analysis/trust4/trust4_report.tsv",
+            "/rna/analysis/fusion/fusion_predictions.tsv",
+            "/rna/analysis/msisensor/msisensor_report.txt",
+            "/rna/analysis/msisensor/msisensor.txt",
+            "/rna/analysis/neoantigen/genotype.json",
+        ]
+    ),
     "WES Analysis": FacetConfig(["/wes/analysis/report.tar.gz"]),
     "TCR": FacetConfig(["/tcr_analysis/report_trial.tar.gz"]),
     "mIF": FacetConfig(["/mif/roi_/cell_seg_data.txt"]),
